#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_BITINCREMENT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_BITINCREMENT_HPP_INCLUDED

#include <boost/simd/constant/include/constants/bitincrement.hpp>

#endif
